#!/usr/bin/python

#My first viewer

import wx
import Image
import ImageChops

class Viewer (wx.Frame):
    def __init__(self, parent, id, title):
        wx.Frame.__init__ (self, parent, id, title, size=(690,480))

        self.panelSize = (300,200)
        self.panel1 = wx.Panel(self, -1,(30,20), self.panelSize, style=wx.SUNKEN_BORDER)
        
        self.picture1 = wx.StaticBitmap (self.panel1)
        self.panel1.SetBackgroundColour(wx.WHITE)

        self.panel2 = wx.Panel(self, -1,(360,20), self.panelSize, style=wx.SUNKEN_BORDER)
        
        self.picture2 = wx.StaticBitmap (self.panel2)
        self.panel2.SetBackgroundColour(wx.WHITE)


        self.images = ['flowers.bmp', 'goldhill.bmp', 'lenna.bmp']
        names = ['flowers', 'house', 'Lenna']

        self.size = (0,0)
        self.newsize=(0,0)

        wx.ComboBox (self, -1, pos=(30,250), size=(130,-1), choices=names, style=wx.CB_READONLY )
        wx.Button (self, 1, '&Close',(50, 420), (200,-1))
        wx.Button (self, 2, '&Show', (360,250))
        wx.Button (self, 3, '&Invert', (450,250))

        self.sld = wx.Slider(self, -1, 125, 0, 255, (360, 330), (250, -1),
		wx.SL_AUTOTICKS | wx.SL_HORIZONTAL | wx.SL_LABELS)

        self.Bind(wx.EVT_BUTTON, self.OnClose, id=1)
        self.Bind(wx.EVT_COMBOBOX, self.OnSelect)
        self.Bind(wx.EVT_SLIDER, self.OnChange)
        self.Bind(wx.EVT_BUTTON, self.OnShow, id=2)
        self.Bind(wx.EVT_BUTTON, self.OnInvert, id=3)
        
        
        self.Centre()
        self.Show(True)
        #self.Destroy()
    

    def thresholding(self,im,mode,thL=125,thRGB=(125,125,125),sh=0):
        """Thresholding function for "L" and "RGB" images.    
        thL - threshold value
        thRGB - tuple of threshold values: (thR, thG, thB)
        2010.03.05"""
    
        fn="thresholding"
        if(sh): print "Function %s" %fn


        if (mode =="L"):
            if(sh): print "***8 pixels, gray scale level image"
            return im.point(lambda i: i>thL and 255)
        if(mode =="RGB"):
            if(sh) : print "***RBB image"
            rgb = im.split()
            r = rgb[0].point(lambda i: i>thRGB[0] and 255)
            g = rgb[1].point(lambda i: i>thRGB[1] and 255)
            b = rgb[2].point(lambda i: i>thRGB[2] and 255)        
            return Image.merge(im.mode, (r,g,b) )

    def OnInvert(self, event):
        item = event.GetSelection()
        self.picture2.SetFocus()

        if(self.newsize[0]!=0 and self.newsize[1]!=0):
            self.panel2.SetSize(self.newsize)

            nnpil = ImageChops.invert (self.npil)          

            data = nnpil.tostring()
            image = wx.EmptyImage(self.npil.size[0], self.npil.size[1])
            image.SetData(data)
            self.picture2.SetBitmap( wx.BitmapFromImage(image))
            
        
    def OnShow(self, event):
        item = event.GetSelection()
        self.picture2.SetFocus()

        if(self.newsize[0]!=0 and self.newsize[1]!=0):
            self.panel2.SetSize(self.newsize)

            data = self.npil.tostring()
            image = wx.EmptyImage(self.npil.size[0], self.npil.size[1])
            image.SetData(data)
            self.picture2.SetBitmap( wx.BitmapFromImage(image))
        
        
        

    def OnChange(self, event):
        if(self.newsize[0]!=0 and self.newsize[1]!=0):
            v=self.sld.GetValue()
            nnpil=self.thresholding(self.npil,self.npil.mode, v, (v,v,v))
            #nnpil.save("img_th.bmp")

            data = nnpil.tostring()
            image = wx.EmptyImage(self.npil.size[0], self.npil.size[1])
            image.SetData(data)
            self.picture2.SetBitmap( wx.BitmapFromImage(image))
        
    def OnClose(self, event):
        self.Close()

    def OnSelect(self, event):
        item = event.GetSelection()
        #print item
        #print self.size

        self.picture1.SetFocus()

        pil = Image.open('images/'+self.images[item])

        self.size = pil.size
        if(self.size[0]>self.size[1]):
            self.coef = float(self.panelSize[0])/float(self.size[0])
        else:
            self.coef = float(self.panelSize[1])/float(self.size[1])

        #print self.coef    
        self.newsize = (int(self.size[0]*self.coef), int(self.size[1]*self.coef))            
        self.panel1.SetSize(self.newsize)
        
        self.npil = pil.convert("RGB")
        self.npil = self.npil.resize(self.newsize)
        data = self.npil.tostring()
        image = wx.EmptyImage(self.npil.size[0], self.npil.size[1])
        image.SetData(data)
        self.picture1.SetBitmap( wx.BitmapFromImage(image))
        #print self.size

app = wx.App ()
Viewer(None, -1, 'IP&CG - my first image viewer ;-)')
app.MainLoop()
